==> spip_3.2.11.orig.tar.xz: ecrire/lang/public_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_lms
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'accueil_site' => 'Acuelh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles de quel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles de quela rubrica',
	'aucun_article' => 'I a brisa d’article a quela adreça ',
	'aucun_auteur' => 'I a brisa d’autor a quela adreça ',
	'aucun_site' => 'I a brisa de sit a quela adreça ',
	'aucune_breve' => 'I a brisa de breva a quela adreça ',
	'aucune_rubrique' => 'I a brisa de rubrica a quela adreça ',
	'autres_breves' => 'Autras brevas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bonjorn',

	// C
	'commenter_site' => 'Comentar queu sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrier apondon',
	'dernieres_breves' => 'Darrieras brevas',
	'derniers_articles' => 'Darriers articles',
	'derniers_commentaires' => 'Darriers comentaris',
	'derniers_messages_forum' => 'Darriers messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde text de',
	'en_reponse' => 'En responsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau mesme autor',
	'meme_rubrique' => 'Dins la mesma rubrica',
	'memes_auteurs' => 'Daus mesmes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo mesme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats subre lo web',
	'nouveaux_articles' => 'Articles nuòus',
	'nouvelles_breves' => 'Brevas nuòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podetz participar a la vida de queu sit e prepausar los articles vòstres en vos inscriure çai jos. Recebretz còp sec un e-mail que vos indicará vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podetz prepausar un sit d’apondre a questa rubrica:',

	// R
	'repondre_article' => 'Respondre a quel article',
	'repondre_breve' => 'Respondre a quela breva',
	'resultats_recherche' => 'Resultats de la recercha',
	'retour_debut_forums' => 'Retorn au començament daus forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat emb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguda',
	'sur_web' => 'Subre lo web',
	'syndiquer_rubrique' => 'Sindicar quela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Quela letra recensa los articles e brevas publicats dempuei', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vesetz en linha'
);

==> spip_4.4.6+dfsg.orig.tar.xz: ecrire/lang/public_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/public?lang_cible=oc_lms
// ** ne pas modifier le fichier **

return [

	// A
	'accueil_site' => 'Acuelh dau sit', # MODIF
	'articles' => 'Articles',
	'articles_auteur' => 'Articles de quel autor',
	'articles_populaires' => 'Los articles mai populars',
	'articles_rubrique' => 'Articles de quela rubrica',
	'aucun_article' => 'I a brisa d’article a quela adreça ',
	'aucun_auteur' => 'I a brisa d’autor a quela adreça ',
	'aucun_site' => 'I a brisa de sit a quela adreça ',
	'aucune_breve' => 'I a brisa de breva a quela adreça ',
	'aucune_rubrique' => 'I a brisa de rubrica a quela adreça ',
	'autres_breves' => 'Autras brevas',
	'autres_groupes_mots_clefs' => 'Autres grops de mots clau',
	'autres_sites' => 'Autres sits',

	// B
	'bonjour' => 'Bonjorn',

	// C
	'commenter_site' => 'Comentar queu sit',

	// D
	'date' => 'Data',
	'dernier_ajout' => 'Darrier apondon',
	'dernieres_breves' => 'Darrieras brevas',
	'derniers_articles' => 'Darriers articles',
	'derniers_commentaires' => 'Darriers comentaris',
	'derniers_messages_forum' => 'Darriers messatges publicats dins los forums',

	// E
	'edition_mode_texte' => 'Edicion en mòde text de',
	'en_reponse' => 'En responsa a:',
	'en_resume' => 'En resumit',
	'envoyer_message' => 'Mandar un messatge',
	'espace_prive' => 'Espaci privat',

	// H
	'hierarchie_site' => 'Ierarquia dau sit',

	// J
	'jours' => 'jorns',

	// M
	'meme_auteur' => 'Dau mesme autor',
	'meme_rubrique' => 'Dins la mesma rubrica',
	'memes_auteurs' => 'Daus mesmes autors',
	'message' => 'Messatge',
	'messages_forum' => 'Messatges de forum', # MODIF
	'messages_recents' => 'Los messatges de forums mai recents',
	'mots_clefs' => 'Mots clau',
	'mots_clefs_meme_groupe' => 'Mots clau dins lo mesme grop',

	// N
	'navigation' => 'Navigacion',
	'nom' => 'Nom',
	'nouveautes' => 'Las novetats',
	'nouveautes_web' => 'Novetats subre lo web',
	'nouveaux_articles' => 'Articles nuòus',
	'nouvelles_breves' => 'Brevas nuòvas',

	// P
	'page_precedente' => 'pagina precedenta',
	'page_suivante' => 'pagina seguenta',
	'par_auteur' => 'per ',
	'participer_site' => 'Podetz participar a la vida de queu sit e prepausar los articles vòstres en vos inscriure çai jos. Recebretz còp sec un e-mail que vos indicará vòstres còdes per accedir a l’espaci privat dau sit.',
	'plan_site' => 'Plan dau sit',
	'popularite' => 'Popularitat',
	'poster_message' => 'Postar un messatge',
	'proposer_site' => 'Podetz prepausar un sit d’apondre a questa rubrica:',

	// R
	'repondre_article' => 'Respondre a quel article',
	'repondre_breve' => 'Respondre a quela breva',
	'resultats_recherche' => 'Resultats de la recercha',
	'retour_debut_forums' => 'Retorn au començament daus forums',
	'rubrique' => 'Rubrica',
	'rubriques' => 'Rubricas',

	// S
	'signatures_petition' => 'Signaturas',
	'site_realise_avec_spip' => 'Sit realizat emb SPIP',
	'sites_web' => 'Sits web',
	'sous_rubriques' => 'Sosrubricas',
	'suite' => 'seguda',
	'sur_web' => 'Subre lo web',
	'syndiquer_rubrique' => 'Sindicar quela rubrica',
	'syndiquer_site' => 'Sindicar tot lo sit',

	// T
	'texte_lettre_information' => 'Vaicí la letra d’informacion dau sit',
	'texte_lettre_information_2' => 'Quela letra recensa los articles e brevas publicats dempuei', # MODIF

	// V
	'ver_imprimer' => 'Version d’estampar',
	'voir_en_ligne' => 'Vesetz en linha',
];
